## What's Changed

1. 新增：支持为 OpenAI API 提供商自定义请求头 ([#3581](https://github.com/AstrBotDevs/AstrBot/issues/3581))
2. 新增：为 WebChat 为 Thinking 模型添加思考过程展示功能；支持快捷切换流式输出 / 非流式输出。([#3632](https://github.com/AstrBotDevs/AstrBot/issues/3632))
3. 新增：优化插件调用 LLM 和 Agent 的路径，为 Context 类引入多个调用 LLM 和 Agent 的便捷方法 ([#3636](https://github.com/AstrBotDevs/AstrBot/issues/3636))
4. 优化：改善不支持流式输出的消息平台的回退策略 ([#3547](https://github.com/AstrBotDevs/AstrBot/issues/3547))
5. 优化：当同一个会话（umo）下同时有多个请求时，执行排队处理，避免并发请求导致的上下文混乱问题 ([#3607](https://github.com/AstrBotDevs/AstrBot/issues/3607))
6. 优化：优化 WebUI 的登录界面和 Changelog 页面的显示效果
7. 修复：修复在知识库名字过长的情况下，“选择知识库”按钮显示异常的问题 ([#3582](https://github.com/AstrBotDevs/AstrBot/issues/3582))
8. 修复：修复部分情况下，分段消息发送时导致的死锁问题（由 PR #3607 引入）
9. 修复：钉钉适配器使用部分指令无法生效的问题 ([#3634](https://github.com/AstrBotDevs/AstrBot/issues/3634))
10. 其他：为部分适配器添加缺失的 send_streaming 方法 ([#3545](https://github.com/AstrBotDevs/AstrBot/issues/3545))
